tiled.query\_registration.QueryRegistry
=======================================

.. currentmodule:: tiled.query_registration

.. autoclass:: QueryRegistry

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~QueryRegistry.__init__
      ~QueryRegistry.register
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~QueryRegistry.name_to_query_type
      ~QueryRegistry.query_type_to_name
   
   